==> zio-aws-sfn_2.12-7.28.29.6-sources.jar: zio/aws/sfn/model/StartSyncExecutionRequest.scala <==
package zio.aws.sfn.model
import zio.ZIO
import zio.aws.sfn.model.primitives.{TraceHeader, SensitiveData, Name, Arn}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StartSyncExecutionRequest(
    stateMachineArn: Arn,
    name: Optional[Name] = Optional.Absent,
    input: Optional[SensitiveData] = Optional.Absent,
    traceHeader: Optional[TraceHeader] = Optional.Absent,
    includedData: Optional[zio.aws.sfn.model.IncludedData] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest = {
    import StartSyncExecutionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest
      .builder()
      .stateMachineArn(Arn.unwrap(stateMachineArn): java.lang.String)
      .optionallyWith(name.map(value => Name.unwrap(value): java.lang.String))(
        _.name
      )
      .optionallyWith(
        input.map(value => SensitiveData.unwrap(value): java.lang.String)
      )(_.input)
      .optionallyWith(
        traceHeader.map(value => TraceHeader.unwrap(value): java.lang.String)
      )(_.traceHeader)
      .optionallyWith(includedData.map(value => value.unwrap))(_.includedData)
      .build()
  }
  def asReadOnly: zio.aws.sfn.model.StartSyncExecutionRequest.ReadOnly =
    zio.aws.sfn.model.StartSyncExecutionRequest.wrap(buildAwsValue())
}
object StartSyncExecutionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sfn.model.StartSyncExecutionRequest =
      zio.aws.sfn.model.StartSyncExecutionRequest(
        stateMachineArn,
        name.map(value => value),
        input.map(value => value),
        traceHeader.map(value => value),
        includedData.map(value => value)
      )
    def stateMachineArn: Arn
    def name: Optional[Name]
    def input: Optional[SensitiveData]
    def traceHeader: Optional[TraceHeader]
    def includedData: Optional[zio.aws.sfn.model.IncludedData]
    def getStateMachineArn: ZIO[Any, Nothing, Arn] =
      ZIO.succeed(stateMachineArn)
    def getName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("name", name)
    def getInput: ZIO[Any, AwsError, SensitiveData] =
      AwsError.unwrapOptionField("input", input)
    def getTraceHeader: ZIO[Any, AwsError, TraceHeader] =
      AwsError.unwrapOptionField("traceHeader", traceHeader)
    def getIncludedData: ZIO[Any, AwsError, zio.aws.sfn.model.IncludedData] =
      AwsError.unwrapOptionField("includedData", includedData)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest
  ) extends zio.aws.sfn.model.StartSyncExecutionRequest.ReadOnly {
    override val stateMachineArn: Arn =
      zio.aws.sfn.model.primitives.Arn(impl.stateMachineArn())
    override val name: Optional[Name] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.sfn.model.primitives.Name(value))
    override val input: Optional[SensitiveData] = zio.aws.core.internal
      .optionalFromNullable(impl.input())
      .map(value => zio.aws.sfn.model.primitives.SensitiveData(value))
    override val traceHeader: Optional[TraceHeader] = zio.aws.core.internal
      .optionalFromNullable(impl.traceHeader())
      .map(value => zio.aws.sfn.model.primitives.TraceHeader(value))
    override val includedData: Optional[zio.aws.sfn.model.IncludedData] =
      zio.aws.core.internal
        .optionalFromNullable(impl.includedData())
        .map(value => zio.aws.sfn.model.IncludedData.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest
  ): zio.aws.sfn.model.StartSyncExecutionRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sfn_3-5.17.211.1-sources.jar: zio/aws/sfn/model/StartSyncExecutionRequest.scala <==
package zio.aws.sfn.model
import zio.ZIO
import zio.aws.sfn.model.primitives.{TraceHeader, SensitiveData, Name, Arn}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class StartSyncExecutionRequest(
    stateMachineArn: Arn,
    name: Optional[Name] = Optional.Absent,
    input: Optional[SensitiveData] = Optional.Absent,
    traceHeader: Optional[TraceHeader] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest = {
    import StartSyncExecutionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest
      .builder()
      .stateMachineArn(Arn.unwrap(stateMachineArn): java.lang.String)
      .optionallyWith(name.map(value => Name.unwrap(value): java.lang.String))(
        _.name
      )
      .optionallyWith(
        input.map(value => SensitiveData.unwrap(value): java.lang.String)
      )(_.input)
      .optionallyWith(
        traceHeader.map(value => TraceHeader.unwrap(value): java.lang.String)
      )(_.traceHeader)
      .build()
  }
  def asReadOnly: zio.aws.sfn.model.StartSyncExecutionRequest.ReadOnly =
    zio.aws.sfn.model.StartSyncExecutionRequest.wrap(buildAwsValue())
}
object StartSyncExecutionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sfn.model.StartSyncExecutionRequest =
      zio.aws.sfn.model.StartSyncExecutionRequest(
        stateMachineArn,
        name.map(value => value),
        input.map(value => value),
        traceHeader.map(value => value)
      )
    def stateMachineArn: Arn
    def name: Optional[Name]
    def input: Optional[SensitiveData]
    def traceHeader: Optional[TraceHeader]
    def getStateMachineArn: ZIO[Any, Nothing, Arn] =
      ZIO.succeed(stateMachineArn)
    def getName: ZIO[Any, AwsError, Name] =
      AwsError.unwrapOptionField("name", name)
    def getInput: ZIO[Any, AwsError, SensitiveData] =
      AwsError.unwrapOptionField("input", input)
    def getTraceHeader: ZIO[Any, AwsError, TraceHeader] =
      AwsError.unwrapOptionField("traceHeader", traceHeader)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest
  ) extends zio.aws.sfn.model.StartSyncExecutionRequest.ReadOnly {
    override val stateMachineArn: Arn =
      zio.aws.sfn.model.primitives.Arn(impl.stateMachineArn())
    override val name: Optional[Name] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value => zio.aws.sfn.model.primitives.Name(value))
    override val input: Optional[SensitiveData] = zio.aws.core.internal
      .optionalFromNullable(impl.input())
      .map(value => zio.aws.sfn.model.primitives.SensitiveData(value))
    override val traceHeader: Optional[TraceHeader] = zio.aws.core.internal
      .optionalFromNullable(impl.traceHeader())
      .map(value => zio.aws.sfn.model.primitives.TraceHeader(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sfn.model.StartSyncExecutionRequest
  ): zio.aws.sfn.model.StartSyncExecutionRequest.ReadOnly = new Wrapper(impl)
}
